//+------------------------------------------------------------------+
//|                                               AMG End of Period.mq4 |
//|                               Copyright 2014, AMG Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2014, AMG Software Corp."
#property link      "http://www.mql5.com"
#property version   "1.00"
#property strict
#property indicator_chart_window
#property indicator_buffers 8
#property indicator_color1 DarkSlateGray
#property indicator_color2 DarkSlateGray
#property indicator_color3 DarkSlateGray
#property indicator_color4 DarkSlateGray
#property indicator_color5 DarkSlateGray
#property indicator_color6 DarkSlateGray
#property indicator_color7 Red
#property indicator_color8 Red

// external parameters  
extern bool EndOfDay = true;
extern bool EndOfWeek = true;
extern bool EndOfMonth = true; 
extern bool EndOfQuarter = true;  
                                 

// Global variables
double l1UpBuffer[];
double l1DnBuffer[];
double l2UpBuffer[];
double l2DnBuffer[];
double l3UpBuffer[];
double l3DnBuffer[];
double l4UpBuffer[];
double l4DnBuffer[];

string prefix = "eop_";
string shortName = "AMG End of Period";

int init()
{
   IndicatorBuffers(6);
   SetIndexStyle(0,DRAW_HISTOGRAM,STYLE_DOT,1);
   SetIndexStyle(1,DRAW_HISTOGRAM,STYLE_DOT,1);
   SetIndexStyle(2,DRAW_HISTOGRAM,STYLE_DASH,1);
   SetIndexStyle(3,DRAW_HISTOGRAM,STYLE_DASH,1);
   SetIndexStyle(4,DRAW_HISTOGRAM,STYLE_SOLID,1);
   SetIndexStyle(5,DRAW_HISTOGRAM,STYLE_SOLID,1);
   SetIndexStyle(6,DRAW_HISTOGRAM,STYLE_SOLID,1);
   SetIndexStyle(7,DRAW_HISTOGRAM,STYLE_SOLID,1);
   
   SetIndexBuffer(0,l1UpBuffer);
   SetIndexBuffer(1,l1DnBuffer);
   
   SetIndexBuffer(2,l2UpBuffer);
   SetIndexBuffer(3,l2DnBuffer);
   
   SetIndexBuffer(4,l3UpBuffer);
   SetIndexBuffer(5,l3DnBuffer);
   
   SetIndexBuffer(6,l4UpBuffer);
   SetIndexBuffer(7,l4DnBuffer);
 
   IndicatorShortName(shortName);
   
   return(INIT_SUCCEEDED);
}


void OnDeinit(const int reason)
{
   ObjectsDeleteAll();
   //ResetHud();
}


void ResetHud()
{

}

void start()
{
   int counted_bars = IndicatorCounted();
   if(counted_bars < 0) counted_bars=0;
   if(counted_bars > 0) counted_bars--;
   int limit = Bars-counted_bars;

   for(int i = 0 ;i <= limit ;i++)
   {
      datetime t = iTime(Symbol(), Period(), i);
      
      if(IsFriday(t) && IsEndOfDay(t) && DisplayEndOfWeek())
      {   
         int barShift = iBarShift(Symbol(), PERIOD_W1, Time[i], false);                       
         l2UpBuffer[i] = iHigh(Symbol(), PERIOD_W1, barShift);
         l2DnBuffer[i] = iLow(Symbol(), PERIOD_W1, barShift);
      }
      else if(IsEndOfDay(t) && DisplayEndOfDay())
      {
         int barShift = iBarShift(Symbol(),PERIOD_D1,Time[i]);
         l1UpBuffer[i] = iHigh(Symbol(),PERIOD_D1, barShift);
         l1DnBuffer[i] = iLow(Symbol(),PERIOD_D1, barShift);
      }    
   }
   
   return;
}

bool DisplayEndOfDay()
{
   return EndOfDay && Period() < PERIOD_D1;
}

bool DisplayEndOfWeek()
{
   return EndOfWeek && Period() <= PERIOD_D1;
}

bool DisplayEndOfMonth()
{
   return EndOfMonth && Period() <= PERIOD_W1;
}

bool DisplayEndOfQuarter()
{
   return EndOfQuarter;
}

// End of day is 5pm NY time
bool IsEndOfDay(datetime t)
{
   return TimeHour(t) == 17;
}


// 0-Sunday,1,2,3,4,5,6
bool IsFriday(datetime t)
{
   return TimeDayOfWeek(t) == 5;
}
